import { getProgramDerivedAddress, getAddressEncoder, getUtf8Encoder, address, getU8Encoder } from '@solana/web3.js';

// src/pdas.ts
async function findAssociatedTokenAccountPda(seeds, config = {}) {
  const {
    programAddress = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getAddressEncoder().encode(seeds.owner),
      getAddressEncoder().encode(seeds.tokenProgram),
      getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findMetadataPda(seeds, config = {}) {
  const {
    programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("metadata"),
      getAddressEncoder().encode(programAddress),
      getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findEditionPda(seeds, config = {}) {
  const {
    programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("metadata"),
      getAddressEncoder().encode(programAddress),
      getAddressEncoder().encode(seeds.mint),
      getUtf8Encoder().encode("edition")
    ]
  });
}
async function findTokenRecordPda(seeds, config = {}) {
  const {
    programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("metadata"),
      getAddressEncoder().encode(programAddress),
      getAddressEncoder().encode(seeds.mint),
      getUtf8Encoder().encode("token_record"),
      getAddressEncoder().encode(seeds.token)
    ]
  });
}
async function findWnsApprovePda(seeds, config = {}) {
  const {
    programAddress = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("approve-account"),
      getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findWnsDistributionPda(seeds, config = {}) {
  const {
    programAddress = "diste3nXmK7ddDTs1zb6uday6j4etCa9RChD8fJ1xay"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getAddressEncoder().encode(seeds.collection),
      getAddressEncoder().encode(
        seeds.paymentMint ?? address("11111111111111111111111111111111")
      )
    ]
  });
}
async function findExtraAccountMetasPda(seeds, config) {
  return await getProgramDerivedAddress({
    programAddress: config.programAddress,
    seeds: [
      getUtf8Encoder().encode("extra-account-metas"),
      getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findFeeVaultPda(seeds) {
  const bytes = getAddressEncoder().encode(seeds.address);
  const lastByte = bytes[bytes.length - 1];
  return await getProgramDerivedAddress({
    programAddress: address("TFEEgwDP6nn1s8mMX2tTNPPz8j2VomkphLUmyxKm17A"),
    seeds: [
      getUtf8Encoder().encode("fee_vault"),
      getU8Encoder().encode(lastByte)
    ]
  });
}
async function findNftReceiptPda(seeds, config) {
  return await getProgramDerivedAddress({
    programAddress: config.programAddress,
    seeds: [
      getUtf8Encoder().encode("nft_receipt"),
      getAddressEncoder().encode(seeds.mint),
      getAddressEncoder().encode(seeds.state)
    ]
  });
}
async function findTreeAuthorityPda(seeds, config = {}) {
  const {
    programAddress = "BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [getAddressEncoder().encode(seeds.merkleTree)]
  });
}
async function findTswapNftEscrowPda(seeds, config = {}) {
  const {
    programAddress = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("nft_escrow"),
      getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findTswapNftDepositReceiptPda(seeds, config = {}) {
  const {
    programAddress = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("nft_receipt"),
      getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findTswapSolEscrowPda(seeds, config = {}) {
  const {
    programAddress = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("sol_escrow"),
      getAddressEncoder().encode(seeds.pool)
    ]
  });
}
async function findTswapSingleListingPda(seeds, config = {}) {
  const {
    programAddress = "TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("single_listing"),
      getAddressEncoder().encode(seeds.mint)
    ]
  });
}
var resolveMetadata = async ({
  accounts
}) => {
  return {
    value: await findMetadataPda({
      mint: expectAddress(accounts.mint?.value)
    })
  };
};
var resolveEditionFromTokenStandard = async ({
  accounts,
  args
}) => {
  switch (args.tokenStandard) {
    case 0 /* NonFungible */:
    case 3 /* NonFungibleEdition */:
    case 4 /* ProgrammableNonFungible */:
    case 5 /* ProgrammableNonFungibleEdition */:
      return {
        value: await findEditionPda({
          mint: expectAddress(accounts.mint?.value)
        })
      };
    default:
      return { value: null };
  }
};
var resolveOwnerTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.ownerTa?.value)
    })
  } : { value: null };
};
var resolveTakerTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.takerTa?.value)
    })
  } : { value: null };
};
var resolveListTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.listTa?.value)
    })
  } : { value: null };
};
var resolveBidTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.bidTa?.value)
    })
  } : { value: null };
};
var resolveBuyerTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.buyerTa?.value)
    })
  } : { value: null };
};
var resolveSellerTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.sellerTa?.value)
    })
  } : { value: null };
};
var resolveSourceTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.sourceTa?.value)
    })
  } : { value: null };
};
var resolveDestinationTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.destinationTa?.value)
    })
  } : { value: null };
};
var resolvePoolTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.poolTa?.value)
    })
  } : { value: null };
};
var resolveTokenMetadataProgramFromTokenStandard = ({
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } : { value: null };
};
var resolveAuthorizationRulesProgramFromTokenStandard = ({
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: "auth9SigNpDKz4sJJ1DfCTuZrZNSAgh9sFD3rboVmgg"
  } : { value: null };
};
var resolveSysvarInstructionsFromTokenStandard = ({
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: "Sysvar1nstructions1111111111111111111111111"
  } : { value: null };
};
var resolveListAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.listState?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolveBidAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.bidState?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolveOwnerAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.owner?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolveBuyerAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.buyer?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolveSellerAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.seller?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolveTakerAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.taker?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolveSourceAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.source?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolveDestinationAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.destination?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolvePoolAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.pool?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolveOwnerCurrencyAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.owner?.value),
      mint: expectAddress(accounts.currency?.value),
      tokenProgram: expectAddress(accounts.currencyTokenProgram?.value)
    })
  };
};
var resolveFeeVaultCurrencyAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.feeVault?.value),
      mint: expectAddress(accounts.currency?.value),
      tokenProgram: expectAddress(accounts.currencyTokenProgram?.value)
    })
  };
};
var resolvePayerCurrencyAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.payer?.value),
      mint: expectAddress(accounts.currency?.value),
      tokenProgram: expectAddress(accounts.currencyTokenProgram?.value)
    })
  };
};
var resolveDistributionCurrencyAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.distribution?.value),
      mint: expectAddress(accounts.currency?.value),
      tokenProgram: expectAddress(accounts.currencyTokenProgram?.value)
    })
  };
};
var resolveMakerBrokerCurrencyAta = async ({
  accounts
}) => {
  if (!accounts.makerBroker.value) {
    return { value: null };
  }
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.makerBroker?.value),
      mint: expectAddress(accounts.currency?.value),
      tokenProgram: expectAddress(accounts.currencyTokenProgram?.value)
    })
  };
};
var resolveTakerBrokerCurrencyAta = async ({
  accounts
}) => {
  if (!accounts.takerBroker.value) {
    return { value: null };
  }
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.takerBroker?.value),
      mint: expectAddress(accounts.currency?.value),
      tokenProgram: expectAddress(accounts.currencyTokenProgram?.value)
    })
  };
};
var resolvePoolNftReceipt = async ({
  accounts
}) => {
  return {
    value: await findNftReceiptPda(
      {
        mint: expectAddress(accounts.mint?.value),
        state: expectAddress(accounts.pool?.value)
      },
      { programAddress: address("TAMM6ub33ij1mbetoMyVBLeKY5iP41i4UPUJQGkhfsg") }
    )
  };
};
var resolveOrderNftReceipt = async ({
  accounts
}) => {
  return {
    value: await findNftReceiptPda(
      {
        mint: expectAddress(accounts.mint?.value),
        state: expectAddress(accounts.orderState?.value)
      },
      { programAddress: address("TLoCKic2wGJm7VhZKumih4Lc35fUhYqVMgA4j389Buk") }
    )
  };
};
var resolveWnsApprovePda = async ({
  accounts
}) => {
  return {
    value: await findWnsApprovePda({
      mint: expectAddress(accounts.mint?.value)
    })
  };
};
var resolveWnsDistributionPda = async ({
  args
}) => {
  return {
    value: await findWnsDistributionPda({
      collection: expectAddress(args.collection),
      paymentMint: args.paymentMint
    })
  };
};
var resolveWnsExtraAccountMetasPda = async ({
  accounts
}) => {
  return {
    value: await findExtraAccountMetasPda(
      {
        mint: expectAddress(accounts.mint?.value)
      },
      { programAddress: expectAddress(accounts.wnsProgram?.value) }
    )
  };
};
var resolveTreeAuthorityPda = async ({
  accounts
}) => {
  return {
    value: await findTreeAuthorityPda(
      {
        merkleTree: expectAddress(accounts.merkleTree?.value)
      },
      { programAddress: expectAddress(accounts.bubblegumProgram?.value) }
    )
  };
};
var resolveOrderAta = async ({
  accounts
}) => {
  return {
    value: await findAssociatedTokenAccountPda({
      owner: expectAddress(accounts.orderVault?.value),
      mint: expectAddress(accounts.mint?.value),
      tokenProgram: expectAddress(accounts.tokenProgram?.value)
    })
  };
};
var resolveOrderTokenRecordFromTokenStandard = async ({
  accounts,
  args
}) => {
  return args.tokenStandard === 4 /* ProgrammableNonFungible */ || args.tokenStandard === 5 /* ProgrammableNonFungibleEdition */ ? {
    value: await findTokenRecordPda({
      mint: expectAddress(accounts.mint?.value),
      token: expectAddress(accounts.orderVaultTa?.value)
    })
  } : { value: null };
};
var resolveTswapNftEscrowPda = async ({
  args
}) => {
  return {
    value: await findTswapNftEscrowPda({
      mint: expectAddress(args.mint)
    })
  };
};
var resolveTswapNftDepositReceiptPda = async ({
  args
}) => {
  return {
    value: await findTswapNftDepositReceiptPda({
      mint: expectAddress(args.mint)
    })
  };
};
var resolveTswapSolEscrowPda = async ({
  args
}) => {
  return {
    value: await findTswapSolEscrowPda({
      pool: expectAddress(args.pool)
    })
  };
};
var resolveTswapSingleListingPda = async ({
  args
}) => {
  return {
    value: await findTswapSingleListingPda({
      mint: expectAddress(args.mint)
    })
  };
};
var resolveEscrowProgramFromSharedEscrow = ({
  accounts
}) => {
  return accounts.sharedEscrow?.value ? {
    value: address("TSWAPaqyCSx2KABk68Shruf4rp7CxcNi8hAsbdwmHbN")
  } : { value: null };
};
var resolveBrokersCurrencyAta = async ({
  accounts
}) => {
  const brokers = [accounts.makerBroker, accounts.takerBroker].filter(
    (broker) => broker.value
  );
  if (brokers.length === 0) {
    return [];
  }
  return await Promise.all(
    brokers.map(
      async (broker) => (await findAssociatedTokenAccountPda({
        owner: expectAddress(broker.value),
        mint: expectAddress(accounts.currency?.value),
        tokenProgram: expectAddress(accounts.currencyTokenProgram?.value)
      }))[0]
    )
  );
};
var resolveCreatorsCurrencyAta = async ({
  accounts,
  args
}) => {
  return await Promise.all(
    args.creators.map(
      async (creator) => (await findAssociatedTokenAccountPda({
        owner: expectAddress(creator),
        mint: expectAddress(accounts.currency?.value),
        tokenProgram: expectAddress(accounts.currencyTokenProgram?.value)
      }))[0]
    )
  );
};
var resolveFeeVaultPdaFromListState = async ({
  accounts
}) => {
  return {
    value: await findFeeVaultPda({
      address: expectAddress(accounts.listState?.value)
    })
  };
};
var resolveFeeVaultPdaFromBidState = async ({
  accounts
}) => {
  return {
    value: await findFeeVaultPda({
      address: expectAddress(accounts.bidState?.value)
    })
  };
};

// src/types.ts
var TokenStandard = /* @__PURE__ */ ((TokenStandard2) => {
  TokenStandard2[TokenStandard2["NonFungible"] = 0] = "NonFungible";
  TokenStandard2[TokenStandard2["FungibleAsset"] = 1] = "FungibleAsset";
  TokenStandard2[TokenStandard2["Fungible"] = 2] = "Fungible";
  TokenStandard2[TokenStandard2["NonFungibleEdition"] = 3] = "NonFungibleEdition";
  TokenStandard2[TokenStandard2["ProgrammableNonFungible"] = 4] = "ProgrammableNonFungible";
  TokenStandard2[TokenStandard2["ProgrammableNonFungibleEdition"] = 5] = "ProgrammableNonFungibleEdition";
  return TokenStandard2;
})(TokenStandard || {});

// src/index.ts
function expectAddress(value) {
  if (!value) {
    throw new Error("Expected a Address.");
  }
  if (typeof value === "object" && "address" in value) {
    return value.address;
  }
  if (Array.isArray(value)) {
    return value[0];
  }
  return value;
}

export { TokenStandard, expectAddress, findAssociatedTokenAccountPda, findEditionPda, findExtraAccountMetasPda, findFeeVaultPda, findMetadataPda, findNftReceiptPda, findTokenRecordPda, findTreeAuthorityPda, findTswapNftDepositReceiptPda, findTswapNftEscrowPda, findTswapSingleListingPda, findTswapSolEscrowPda, findWnsApprovePda, findWnsDistributionPda, resolveAuthorizationRulesProgramFromTokenStandard, resolveBidAta, resolveBidTokenRecordFromTokenStandard, resolveBrokersCurrencyAta, resolveBuyerAta, resolveBuyerTokenRecordFromTokenStandard, resolveCreatorsCurrencyAta, resolveDestinationAta, resolveDestinationTokenRecordFromTokenStandard, resolveDistributionCurrencyAta, resolveEditionFromTokenStandard, resolveEscrowProgramFromSharedEscrow, resolveFeeVaultCurrencyAta, resolveFeeVaultPdaFromBidState, resolveFeeVaultPdaFromListState, resolveListAta, resolveListTokenRecordFromTokenStandard, resolveMakerBrokerCurrencyAta, resolveMetadata, resolveOrderAta, resolveOrderNftReceipt, resolveOrderTokenRecordFromTokenStandard, resolveOwnerAta, resolveOwnerCurrencyAta, resolveOwnerTokenRecordFromTokenStandard, resolvePayerCurrencyAta, resolvePoolAta, resolvePoolNftReceipt, resolvePoolTokenRecordFromTokenStandard, resolveSellerAta, resolveSellerTokenRecordFromTokenStandard, resolveSourceAta, resolveSourceTokenRecordFromTokenStandard, resolveSysvarInstructionsFromTokenStandard, resolveTakerAta, resolveTakerBrokerCurrencyAta, resolveTakerTokenRecordFromTokenStandard, resolveTokenMetadataProgramFromTokenStandard, resolveTreeAuthorityPda, resolveTswapNftDepositReceiptPda, resolveTswapNftEscrowPda, resolveTswapSingleListingPda, resolveTswapSolEscrowPda, resolveWnsApprovePda, resolveWnsDistributionPda, resolveWnsExtraAccountMetasPda };
//# sourceMappingURL=index.mjs.map
//# sourceMappingURL=index.mjs.map