import { Address, ProgramDerivedAddress } from '@solana/web3.js';
export type AssociatedTokenAccountSeeds = {
    /** The address of the owner account */
    owner: Address;
    /** The address of the mint account */
    mint: Address;
    /** The address of the token program */
    tokenProgram: Address;
};
export declare function findAssociatedTokenAccountPda(seeds: AssociatedTokenAccountSeeds, config?: {
    programAddress?: Address | undefined;
}): Promise<ProgramDerivedAddress>;
export type MetadataSeeds = {
    /** The address of the mint account */
    mint: Address;
};
export declare function findMetadataPda(seeds: MetadataSeeds, config?: {
    programAddress?: Address | undefined;
}): Promise<ProgramDerivedAddress>;
export type EditionSeeds = {
    /** The address of the mint account */
    mint: Address;
};
export declare function findEditionPda(seeds: EditionSeeds, config?: {
    programAddress?: Address | undefined;
}): Promise<ProgramDerivedAddress>;
export type TokenRecordSeeds = {
    /** The address of the mint account */
    mint: Address;
    /** The address of the token account */
    token: Address;
};
export declare function findTokenRecordPda(seeds: TokenRecordSeeds, config?: {
    programAddress?: Address | undefined;
}): Promise<ProgramDerivedAddress>;
export type WnsApproveSeeds = {
    /** The address of the mint account */
    mint: Address;
};
export declare function findWnsApprovePda(seeds: WnsApproveSeeds, config?: {
    programAddress?: Address | undefined;
}): Promise<ProgramDerivedAddress>;
export type WnsDistributionSeeds = {
    /** The address of the collection account */
    collection: Address;
    /** The address of the payment mint account */
    paymentMint?: Address | null;
};
export declare function findWnsDistributionPda(seeds: WnsDistributionSeeds, config?: {
    programAddress?: Address | undefined;
}): Promise<ProgramDerivedAddress>;
export type ExtraAccountMetasSeeds = {
    /** The address of the mint account */
    mint: Address;
};
export declare function findExtraAccountMetasPda(seeds: ExtraAccountMetasSeeds, config: {
    programAddress: Address;
}): Promise<ProgramDerivedAddress>;
export type FeeVaultSeeds = {
    /** The address of the state account to derive the shard from: e.g. pool, bid, order etc. */
    address: Address;
};
export declare function findFeeVaultPda(seeds: FeeVaultSeeds): Promise<ProgramDerivedAddress>;
export type NftReceiptSeeds = {
    /** The address of the mint account */
    mint: Address;
    /** The address of the state account */
    state: Address;
};
export declare function findNftReceiptPda(seeds: NftReceiptSeeds, config: {
    programAddress: Address;
}): Promise<ProgramDerivedAddress>;
export type TreeAuthoritySeeds = {
    /** The address of the merkle tree */
    merkleTree: Address;
};
export declare function findTreeAuthorityPda(seeds: TreeAuthoritySeeds, config?: {
    programAddress?: Address | undefined;
}): Promise<ProgramDerivedAddress>;
export type TswapNftEscrowSeeds = {
    /** The address of the mint account */
    mint: Address;
};
export declare function findTswapNftEscrowPda(seeds: TswapNftEscrowSeeds, config?: {
    programAddress?: Address | undefined;
}): Promise<ProgramDerivedAddress>;
export type TswapNftDepositReceiptSeeds = {
    /** The address of the mint account */
    mint: Address;
};
export declare function findTswapNftDepositReceiptPda(seeds: TswapNftDepositReceiptSeeds, config?: {
    programAddress?: Address | undefined;
}): Promise<ProgramDerivedAddress>;
export type TswapSolEscrowSeeds = {
    /** The address of the pool account */
    pool: Address;
};
export declare function findTswapSolEscrowPda(seeds: TswapSolEscrowSeeds, config?: {
    programAddress?: Address | undefined;
}): Promise<ProgramDerivedAddress>;
export type TswapSingleListingSeeds = {
    /** The address of the mint account */
    mint: Address;
};
export declare function findTswapSingleListingPda(seeds: TswapSingleListingSeeds, config?: {
    programAddress?: Address | undefined;
}): Promise<ProgramDerivedAddress>;
//# sourceMappingURL=pdas.d.ts.map